@@ -214,7 +214,9 @@ private slots:
 
     void on_setGitPathToolButton_clicked();
 
-    void searchScriptInRepository();
+    void searchScriptInRepository(bool checkForUpdates = false);
+
+    void checkForScriptUpdates();
 
     void on_scriptListWidget_itemChanged(QListWidgetItem *item);
 
@@ -222,6 +224,10 @@ private slots:
 
     void on_cursorWidthResetButton_clicked();
 
+    void on_showSystemTrayCheckBox_toggled(bool checked);
+
+    void on_resetMessageBoxesButton_clicked();
+
 private:
 
     Ui::SettingsDialog *ui;
