@@ -19,6 +19,7 @@
 #include <services/scriptingservice.h>
 #include <QMimeDatabase>
 #include <QTemporaryFile>
+#include <utils/gui.h>
 
 
 Note::Note() {
@@ -1662,17 +1663,20 @@ QString Note::toMarkdownHtml(QString notesPath, int maxImageWidth,
                                                                   fileName));
         } else {
             // for preview
-            // cap the image width at 980px or the note text view width
-            if (image.width() > maxImageWidth) {
-                result.replace(
-                        QRegularExpression("<img src=\"file:\\/\\/" +
-                                           QRegularExpression::escape
-                                                   (windowsSlash + fileName) +
-                                           "\""),
-                        QString("<img width=\"%1\" src=\"file://%2\"").arg(
-                                QString::number(maxImageWidth), windowsSlash +
-                                fileName));
-            }
+            // cap the image width at maxImageWidth (note text view width)
+            int originalWidth = image.width();
+            int displayWidth = (originalWidth > maxImageWidth)
+                    ? maxImageWidth
+                    : originalWidth;
+
+            result.replace(
+                    QRegularExpression("<img src=\"file:\\/\\/" +
+                                       QRegularExpression::escape
+                                               (windowsSlash + fileName) +
+                                       "\""),
+                    QString("<img width=\"%1\" src=\"file://%2\"").arg(
+                            QString::number(displayWidth), windowsSlash +
+                            fileName));
         }
 
         // encode the image base64
@@ -2169,7 +2173,7 @@ void Note::handleNoteRenaming(QString oldFileName, QString newFileName) {
     QString oldUrl = getNoteURL(oldFileName);
     QString newUrl = getNoteURL(newFileName);
 
-    if (QMessageBox::information(
+    if (Utils::Gui::question(
             Q_NULLPTR,
             QObject::tr("Note filename changed"),
             QObject::tr("A change of the note name was detected. Would you "
@@ -2178,7 +2182,7 @@ void Note::handleNoteRenaming(QString oldFileName, QString newFileName) {
                                 "<strong>%2</strong>"
                                 " in <strong>%n</strong> note file(s)?", "",
                         noteCount).arg(oldUrl, newUrl),
-            QMessageBox::Yes, QMessageBox::No) == QMessageBox::Yes) {
+            "note-replace-links") == QMessageBox::Yes) {
         // replace the urls in all found notes
         Q_FOREACH(int noteId, noteIdList) {
                 Note note = Note::fetch(noteId);
