@@ -61,7 +61,7 @@ QMarkdownTextEdit::QMarkdownTextEdit(QWidget *parent)
     this->setLayout(layout);
 
     // add the hidden search widget
-    _searchWidget = new QTextEditSearchWidget(this);
+    _searchWidget = new QPlainTextEditSearchWidget(this);
     this->layout()->addWidget(_searchWidget);
 
     QObject::connect(this, SIGNAL(textChanged()),
@@ -606,7 +606,7 @@ MarkdownHighlighter *QMarkdownTextEdit::highlighter() {
  * @brief Returns the searchWidget instance
  * @return
  */
-QTextEditSearchWidget *QMarkdownTextEdit::searchWidget() {
+QPlainTextEditSearchWidget *QMarkdownTextEdit::searchWidget() {
     return _searchWidget;
 }
 
@@ -781,7 +781,7 @@ void QMarkdownTextEdit::setPlainText(const QString & text) {
 /**
  * Uses an other widget as parent for the search widget
  */
-void QMarkdownTextEdit::initSearchFrame(QWidget *searchFrame) {
+void QMarkdownTextEdit::initSearchFrame(QWidget *searchFrame, bool darkMode) {
     _searchFrame = searchFrame;
 
     // remove the search widget from our layout
@@ -796,6 +796,7 @@ void QMarkdownTextEdit::initSearchFrame(QWidget *searchFrame) {
         layout->setContentsMargins(0, 0, 0, 0);
     }
 
+    _searchWidget->setDarkMode(darkMode);
     layout->addWidget(_searchWidget);
     _searchFrame->setLayout(layout);
 }
@@ -815,12 +816,13 @@ bool QMarkdownTextEdit::handleReturnEntered() {
     QTextCursor c = this->textCursor();
     int position = c.position();
 
-    c.movePosition(QTextCursor::StartOfLine, QTextCursor::KeepAnchor);
+    c.movePosition(QTextCursor::StartOfBlock, QTextCursor::KeepAnchor);
     QString currentLineText = c.selectedText();
 
     // if return is pressed and there is just a list symbol then we want to
     // remove the list symbol
-    QRegularExpression re("^\\s*[+\\-\\*]\\s*$");
+    // Valid listCharacters: '+ ', '-' , '* ', '+ [ ] ', '+ [x] ', '- [ ] ', '- [x] ', '* [ ] ', '* [x] '.
+    QRegularExpression re("^(\\s*)([+|\\-|\\*] \\[(x| )\\]|[+\\-\\*])(\\s+)$");
     QRegularExpressionMatchIterator i = re.globalMatch(currentLineText);
     if (i.hasNext()) {
         c.removeSelectedText();
@@ -828,23 +830,24 @@ bool QMarkdownTextEdit::handleReturnEntered() {
     }
 
     // Check if we are in a list.
-    // We are in a list when we have '* ' or '- ', possibly with preceding
+    // We are in a list when we have '* ', '- ' or '+ ', possibly with preceding
     // whitespace. If e.g. user has entered '**text**' and pressed enter - we
     // don't want do anymore list-stuff.
     QChar char0 = currentLineText.trimmed()[0];
     QChar char1 = currentLineText.trimmed()[1];
-    bool inList = ((char0 == '*' || char0 == '-') && char1 == ' ');
+    bool inList = ((char0 == '*' || char0 == '-' || char0 == '+') && char1 == ' ');
 
     if (inList) {
         // if the current line starts with a list character (possibly after
         // whitespaces) add the whitespaces at the next line too
-        re = QRegularExpression("^(\\s*)([+\\-\\*])(\\s?)");
+        // Valid listCharacters: '+ ', '-' , '* ', '+ [ ] ', '+ [x] ', '- [ ] ', '- [x] ', '* [ ] ', '* [x] '.
+        re = QRegularExpression("^(\\s*)([+|\\-|\\*] \\[(x| )\\]|[+\\-\\*])(\\s+)");
         i = re.globalMatch(currentLineText);
         if (i.hasNext()) {
             QRegularExpressionMatch match = i.next();
             QString whitespaces = match.captured(1);
             QString listCharacter = match.captured(2);
-            QString whitespaceCharacter = match.captured(3);
+            QString whitespaceCharacter = match.captured(4);
 
             c.setPosition(position);
             c.insertText("\n" + whitespaces + listCharacter + whitespaceCharacter);
@@ -870,14 +873,15 @@ bool QMarkdownTextEdit::handleTabEntered(bool reverse) {
         QString currentLineText = c.selectedText();
 
         // check if we want to indent or un-indent a list
-        QRegularExpression re("^(\\s*)([+\\-\\*])(\\s?)$");
+        // Valid listCharacters: '+ ', '-' , '* ', '+ [ ] ', '+ [x] ', '- [ ] ', '- [x] ', '* [ ] ', '* [x] '.
+        QRegularExpression re("^(\\s*)([+|\\-|\\*] \\[(x| )\\]|[+\\-\\*])(\\s+)$");
         QRegularExpressionMatchIterator i = re.globalMatch(currentLineText);
 
         if (i.hasNext()) {
             QRegularExpressionMatch match = i.next();
             QString whitespaces = match.captured(1);
             QString listCharacter = match.captured(2);
-            QString whitespaceCharacter = match.captured(3);
+            QString whitespaceCharacter = match.captured(4);
 
             // add or remove one tabulator key
             if (reverse) {
