@@ -138,6 +138,8 @@ public:
 
     QList<Note> selectedNotes();
 
+    bool jumpToNoteSubFolder(int noteSubFolderId);
+
 protected:
     void closeEvent(QCloseEvent *event);
 
@@ -190,8 +192,6 @@ private slots:
 
     void systemTrayIconClicked(QSystemTrayIcon::ActivationReason reason);
 
-    void on_actionShow_system_tray_triggered(bool checked);
-
     void on_action_Settings_triggered();
 
     void on_actionShow_versions_triggered();
@@ -416,8 +416,6 @@ private slots:
 
     void on_actionFind_notes_in_all_subfolders_triggered();
 
-    void on_actionStart_hidden_triggered(bool checked);
-
     void on_actionImport_notes_from_Evernote_triggered();
 
     void on_actionDelete_orphaned_images_triggered();
@@ -494,6 +492,10 @@ private slots:
 
     void on_actionInsert_attachment_triggered();
 
+    void on_actionAllow_note_editing_triggered(bool checked);
+
+    void on_actionCheck_for_script_updates_triggered();
+
 private:
     Ui::MainWindow *ui;
     QString notesPath;
@@ -855,4 +857,12 @@ private:
 
     void directoryWatcherWorkaround(bool isNotesDirectoryWasModifiedDisabled,
                                     bool alsoHandleNotesWereModified = false);
+
+    bool allowNoteEditing() const;
+
+    void setMenuEnabled(QMenu* menu, bool enabled);
+
+    bool undoFormatting(QString formatter);
+
+    void applyFormatter(QString formatter);
 };
