@@ -709,7 +709,7 @@ bool ScriptingService::startDetachedProcess(QString executablePath,
  *
  * @param executablePath the path of the executable
  * @param parameters a list of parameter strings
- * @param data the data that will be written to the process
+ * @param data the data that will be written to the process (optional)
  * @return the text that was returned by the process
  */
 QByteArray ScriptingService::startSynchronousProcess(
@@ -1324,32 +1324,85 @@ QString ScriptingService::inputDialogGetText(
 }
 
 /**
- * Stores a persistent variables
+ * Stores a persistent variable
  * These variables are accessible globally over all scripts
  * Please use a meaningful prefix in your key like "PersistentVariablesTest/myVar"
  *
- * @param key
- * @param value
+ * @param key {QString}
+ * @param value {QVariant}
  */
 void ScriptingService::setPersistentVariable(const QString &key,
                                              const QVariant &value) {
+    MetricsService::instance()->sendVisitIfEnabled(
+            "scripting/" + QString(__func__));
+
     QSettings settings;
     settings.setValue(QString(PERSISTENT_VARIABLE_SETTINGS_PREFIX) + "/" + key,
                       value);
 }
 
 /**
- * Loads a persistent variables
+ * Loads a persistent variable
  * These variables are accessible globally over all scripts
  *
- * @param key
- * @param defaultValue
+ * @param key {QString}
+ * @param defaultValue {QVariant} return value if the setting doesn't exist (optional)
  * @return
  */
 QVariant ScriptingService::getPersistentVariable(const QString &key,
                                                  const QVariant &defaultValue) {
+    MetricsService::instance()->sendVisitIfEnabled(
+            "scripting/" + QString(__func__));
+
     QSettings settings;
     return settings.value(
             QString(PERSISTENT_VARIABLE_SETTINGS_PREFIX) + "/" + key,
             defaultValue);
 }
+
+/**
+ * Loads an application settings variable
+ *
+ * @param key {QString}
+ * @param defaultValue {QVariant} return value if the setting doesn't exist (optional)
+ * @return
+ */
+QVariant ScriptingService::getApplicationSettingsVariable(
+        const QString &key, const QVariant &defaultValue) {
+    QSettings settings;
+    return settings.value(key, defaultValue);
+}
+
+/**
+ * Jumps to a note subfolder
+ *
+ * @param noteSubFolderPath {QString} path of the subfolder, relative to the note folder
+ * @param separator {QString} separator between parts of the path, default "/"
+ * @return true if jump was successful
+ */
+bool ScriptingService::jumpToNoteSubFolder(const QString &noteSubFolderPath,
+                                           QString separator) {
+    MetricsService::instance()->sendVisitIfEnabled(
+            "scripting/" + QString(__func__));
+
+#ifndef INTEGRATION_TESTS
+    MainWindow *mainWindow = MainWindow::instance();
+    if (mainWindow == Q_NULLPTR) {
+        return false;
+    }
+
+    NoteSubFolder folder = NoteSubFolder::fetchByPathData(noteSubFolderPath,
+                                                          separator);
+
+    if (!folder.isFetched()) {
+        return false;
+    }
+
+    // jump to the note subfolder
+    return mainWindow->jumpToNoteSubFolder(folder.getId());
+#else
+    Q_UNUSED(noteSubFolderPath);
+    Q_UNUSED(separator);
+    return false;
+#endif
+}
