@@ -366,6 +366,7 @@ QByteArray Utils::Misc::startSynchronousProcess(
 #endif
 
     if (!process.waitForStarted()) {
+        qWarning() << __func__ << " - 'process.waitForStarted' returned false";
         return QByteArray();
     }
 
@@ -373,6 +374,7 @@ QByteArray Utils::Misc::startSynchronousProcess(
     process.closeWriteChannel();
 
     if (!process.waitForFinished()) {
+        qWarning() << __func__ << " - 'process.waitForFinished' returned false";
         return QByteArray();
     }
 
@@ -392,6 +394,20 @@ QString Utils::Misc::defaultNotesPath() {
                    portableDataPath() :
                    QDir::homePath() + Utils::Misc::dirSeparator() + "ownCloud";
 
+    // check if the ownCloud path already exists (because the user is using
+    // ownCloud), if not use Nextcloud
+    if (!isInPortableMode()) {
+        // we don't want to use the regular sync path for debugging
+#ifdef QT_DEBUG
+        path.append(".test");
+#endif
+
+        QDir dir(path);
+        if (!dir.exists()) {
+            path = QDir::homePath() + Utils::Misc::dirSeparator() + "Nextcloud";
+        }
+    }
+
     path += Utils::Misc::dirSeparator() + "Notes";
 
     // remove the snap path for Snapcraft builds
