@@ -25,6 +25,7 @@
 #include <QDesktopServices>
 #include <utils/misc.h>
 #include <dialogs/filedialog.h>
+#include <utils/gui.h>
 #include "fontcolorwidget.h"
 #include "ui_fontcolorwidget.h"
 #include "utils/schema.h"
@@ -578,12 +579,11 @@ void FontColorWidget::on_deleteSchemeButton_clicked() {
         return;
     }
 
-    if (QMessageBox::information(
+    if (Utils::Gui::question(
             this,
             tr("Remove schema"),
             tr("Remove current schema? This cannot be undone!"),
-             tr("Remove"), tr("Cancel"), QString::null,
-             0, 1) != 0) {
+            "remove-color-schema") != QMessageBox::Yes) {
         return;
     }
 
@@ -753,10 +753,15 @@ void FontColorWidget::on_fontSizeAdaptionSpinBox_valueChanged(int value) {
 }
 
 /**
- * Open the GitHub issues page to share a schema
+ * Opens a new GitHub issue to share a schema
  */
 void FontColorWidget::on_shareSchemaPushButton_clicked() {
-    QDesktopServices::openUrl(QUrl("https://github.com/pbek/QOwnNotes/issues"));
+    QDesktopServices::openUrl(
+            QUrl("https://github.com/pbek/QOwnNotes/issues/new?title=" +
+                   QUrl::toPercentEncoding("New editor schema: <schema-name>") +
+                   "&body=" + QUrl::toPercentEncoding(
+                    "I want to submit a new editor schema.\n\n"
+                            "(upload your schema)")));
 }
 
 /**
