@@ -15,6 +15,7 @@
 
 #include <QTextBrowser>
 #include <QResizeEvent>
+#include <widgets/qtexteditsearchwidget.h>
 
 class NotePreviewWidget : public QTextBrowser
 {
@@ -22,9 +23,18 @@ class NotePreviewWidget : public QTextBrowser
 
 public:
     explicit NotePreviewWidget(QWidget *parent = 0);
+    void initSearchFrame(QWidget *searchFrame, bool darkMode = false);
+    QTextEditSearchWidget *searchWidget();
 
 protected:
+    QTextEditSearchWidget *_searchWidget;
+    QWidget *_searchFrame;
+
     void resizeEvent(QResizeEvent* event);
+    bool eventFilter(QObject *obj, QEvent *event);
+
+public slots:
+    void hide();
 
 signals:
     void resize(QSize size, QSize oldSize);
